@@ -5,8 +5,9 @@
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- * Copyright (c) 2020 Red Hat, Inc.
  ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 import _ from 'lodash';
 import { gql } from 'apollo-server-express';
@@ -14,19 +15,14 @@ import { gql } from 'apollo-server-express';
 import * as applications from './application';
 import * as channels from './channel';
 import * as subscriptions from './subscription';
-import * as cluster from './cluster';
-import * as compliance from './compliance';
 import * as placementrules from './placementrule';
 import * as filter from './filter';
 import * as overview from './overview';
-import * as occurrence from './occurrence';
 import * as json from './json';
 import * as genericResources from './generic-resources';
 import * as query from './query';
 import * as topology from './topology';
 import * as userAccess from './user-access';
-import * as connection from './connection';
-import * as bmAsset from './bare-metal-asset';
 import * as userAccessAnyNamespaces from './user-access-any-namespaces';
 
 const modules = [
@@ -34,18 +30,13 @@ const modules = [
   channels,
   subscriptions,
   placementrules,
-  cluster,
-  compliance,
   filter,
   overview,
-  occurrence,
   json,
   query,
   genericResources,
   topology,
   userAccess,
-  connection,
-  bmAsset,
   userAccessAnyNamespaces,
 ];
 
